"""
this is the doc string for the pkg_peiwen package.

we modify attributes of the package by editing __init__.py file.
"""

__version__ = "0.1.4" 
# manually set the version of the package here, 
# it should match the version in toml file.


"""
This is the doc for the `pkg_peiwen.function` module.
Put module-level docstring at the top of the module file.
"""

def add_one(x):
    """
    An example function from my example pacakge.

    Add one to the input number.
    """
    return x + 1
